#ifndef __KEYCODE_H
#define __KEYCODE_H

# define KEY_ESC      0x01/*  ESC                      */
# define KEY_1        0x02/*  1                        */
# define KEY_2        0x03/*  2                        */
# define KEY_3        0x04/*  3                        */
# define KEY_4        0x05/*  4                        */
# define KEY_5        0x06/*  5                        */
# define KEY_6        0x07/*  6                        */
# define KEY_7        0x08/*  7                        */
# define KEY_8        0x09/*  8                        */
# define KEY_9        0x0A/*  9                        */
# define KEY_0        0x0B/*  0                        */
# define KEY_A        0x1E/*  A                        */
# define KEY_B        0x30/*  B                        */
# define KEY_C        0x2E/*  C                        */
# define KEY_D        0x20/*  D                        */
# define KEY_E        0x12/*  E                        */
# define KEY_F        0x21/*  F                        */
# define KEY_G        0x22/*  G                        */
# define KEY_H        0x23/*  H                        */
# define KEY_I        0x17/*  I                        */
# define KEY_J        0x24/*  J                        */
# define KEY_K        0x25/*  K                        */
# define KEY_L        0x26/*  L                        */
# define KEY_M        0x32/*  M                        */
# define KEY_N        0x31/*  N                        */
# define KEY_O        0x18/*  O                        */
# define KEY_P        0x19/*  P                        */
# define KEY_Q        0x10/*  Q                        */
# define KEY_R        0x13/*  R                        */
# define KEY_S        0x1F/*  S                        */
# define KEY_T        0x14/*  T                        */
# define KEY_U        0x16/*  U                        */
# define KEY_V        0x2F/*  V                        */
# define KEY_W        0x11/*  W                        */
# define KEY_X        0x2D/*  X                        */
# define KEY_Y        0x15/*  Y                        */
# define KEY_Z        0x2C/*  Z                        */

# define KEY_MINUS    0x0C/*  -   < KEY_ >                */
# define KEY_EQUAL    0x0D/*  =   < + >                */
# define KEY_LPAREN   0x1A/*  [   < { >                */
# define KEY_RPAREN   0x1B/*  ]   < } >                */
# define KEY_SEMI     0x27/*  ;   < : >                */
# define KEY_QUATO    0x28/*  `   < " >                */
# define KEY_BQUATO   0x29/*  `   < ~ >                */
# define KEY_BSLASH   0x2B/*  \   < | >                */
# define KEY_COMMA    0x33/*  ,   < < >                */
# define KEY_DOT      0x34/*  .   < > >                */
# define KEY_SLASH    0x35/*  /   < ? >                */
# define KEY_F1       0x3B/*  Function  1 key          */
# define KEY_F2       0x3C/*  Function  2 key          */
# define KEY_F3       0x3D/*  Function  3 key          */
# define KEY_F4       0x3E/*  Function  4 key          */
# define KEY_F5       0x3F/*  Function  5 key          */
# define KEY_F6       0x40/*  Function  6 key          */
# define KEY_F7       0x41/*  Function  7 key          */
# define KEY_F8       0x42/*  Function  8 key          */
# define KEY_F9       0x43/*  Function  9 key          */
# define KEY_F10      0x44/*  Function 10 key          */
# define KEY_F11      0x57/*  Function 11 key          */
# define KEY_F12      0x58/*  Function 12 key          */

# define KEY_BACKSP   0x0E/*  Back space               */
# define KEY_SPACE    0x39/*  Space                    */
# define KEY_ENTER    0x1C/*  Return or Enter key      */
# define KEY_TAB      0x0F/*  Tab key                  */
# define KEY_LSHIFT   0x2A/*  Left Shift Key           */
# define KEY_RSHIFT   0x36/*  Right Shift Key          */
# define KEY_LCTRL    0x1D/*  Left Control key         */
# define KEY_RCTRL    0x1D/*  Right Control key        */
# define KEY_LALT     0x38/*  Left Alternate key       */
# define KEY_RALT     0x38/*  Right Alternate key      */

# define KEY_HOME     0x4F/*  Home key                 */
# define KEY_PGUP     0x51/*  Page Up                  */
# define KEY_END      0x7A/*  End                      */
# define KEY_PGDN     0x7E/*  Page Down                */
# define KEY_INS      0x53/*  Insert                   */
# define KEY_DEL      0x79/*  Delete                   */
# define KEY_NHOME    0x47/*  Number Keypad  Home      */
# define KEY_NPGUP    0x49/*  Number Keypad  Page Up   */
# define KEY_NEND     0x4F/*  Number Keypad  End       */
# define KEY_NPGDN    0x51/*  Number Keypad  Page Down */
# define KEY_NINS     0x52/*  Number Keypad  Insert    */
# define KEY_NDEL     0x53/*  Number Keypad  Delete    */
# define KEY_NPLUS    0x37/*  Number Keypad Grey + key */
# define KEY_NRET     0x4E/*  Number Keypad Grey ENTER */
# define KEY_NSLASH   0x61/*  Number Keypad Grey / key */
# define KEY_NAST     0x62/*  Number Keypad Grey * key */
# define KEY_NMINUS   0x63/*  Number Keypad Grey - key */
# define KEY_NUMLOCK  0x45/*  Number Lock              */
# define KEY_CAPLOCK  0x3A/*  Caps lock                */
# define KEY_SCRLOCK  0x46/*  Scroll lock              */
# define KEY_UP       0x48/*  Up Arrow                 */
# define KEY_DOWN     0x50/*  Down Arrow               */
# define KEY_LEFT     0x4B/*  Left Arrow               */
# define KEY_RIGHT    0x4D/*  Right Arrow              */

#endif

void interrupt (*oldint)();
unsigned int scan[128]={0};

void interrupt my_key()
{
	unsigned int KeyCode;

	disable();

	KeyCode=inp(0x60);

	if(KeyCode>127)
		scan[KeyCode-128]=0;
	else
	{
		scan[KeyCode]++;
		if(scan[KeyCode]>=255) scan[KeyCode]=0;
	}

	outp(0x20,0x20);
	enable();
}

void Key_In(void)
{
	int i;
	for(i=0;i<128;i++)
		scan[i]=0;

	oldint=getvect(0x09);
	setvect(0x09,my_key);
}

void Key_Close(void)
{
	setvect(0x09,oldint);
}

/*
void main(void)
{
	Key_In();

	while(!scan[KEY_ESC])
	{
		if(scan[KEY_RIGHT])
			break;
	}
	Key_Close();
} */
